@@ -187,17 +187,20 @@ class FeatureCommand(GitFlowCommand):
         p = parent.add_parser('finish', help='Finish a feature branch ' +
             '(with PTintegration).')
         p.set_defaults(func=cls.run_finish)
-        p.add_argument('-F', '--fetch', action='store_true', default=True,
-                help='Fetch from origin before performing local operation.')
+        #p.add_argument('-F', '--no-fetch', action='store_true', default=True,
+        #        help='Fetch from origin before performing local operation.')
         p.add_argument('-r', '--rebase', action='store_true',
                 help='Finish branch by rebasing first.')
-        p.add_argument('-k', '--keep', action='store_true', default=True,
-                help='Keep branch after performing finish.')
+        #p.add_argument('-k', '--keep', action='store_true', default=True,
+        #        help='Keep branch after performing finish.')
         p.add_argument('-D', '--force-delete', action='store_true',
             default=False, help='Force delete feature branch after finish.')
-        p.add_argument('-p', '--full-patch', action='store_true',
-            default=False, help='Post review for the whole branch, not just for '
-                'the last commit')
+        p.add_argument('-n', '--new-review', action='store_true',
+            default=False, help='Post a new review for the whole branch, '
+                'not just for the last commit.')
+        p.add_argument('-P', '--no-push', action='store_true',
+            default=False, help='Do not push the develop branch to origin '
+            'after merging with the feature branch.')
         p.add_argument('nameprefix', nargs='?')
 
     @staticmethod
@@ -206,20 +209,12 @@ class FeatureCommand(GitFlowCommand):
         name = gitflow.nameprefix_or_current('feature', args.nameprefix)
         gitflow.start_transaction('finishing feature branch %s' % name)
         gitflow.finish('feature', name,
-                       fetch=args.fetch, rebase=args.rebase,
-                       keep=args.keep, force_delete=args.force_delete,
-                       tagging_info=None)
+                       fetch=True, rebase=args.rebase,
+                       keep=True, force_delete=args.force_delete,
+                       tagging_info=None, push=(not args.no_push))
         story_id = pivotal.get_story_id_from_branch_name(name)
-        story = pivotal.get_story(story_id)
-        if story['story']['story_type'] == 'chore':
-            labels = story['story'].get('labels', [])
-            if not 'waiting-for-review' in labels:
-                labels += ['waiting-for-review']
-                pivotal.update_story(story_id, labels=labels)
-        else:
-            pivotal.update_story(story_id, current_state='finished')
-
-        gitflow.post_review('feature', name, 'foobar')
+        pivotal.finish_story(story_id)
+        gitflow.post_review('feature', name, post_new=args.new_review)
 
     #- checkout
     @classmethod
@@ -437,7 +432,7 @@ class ReleaseCommand(GitFlowCommand):
         release = gitflow.finish('release', version,
                                  fetch=args.fetch, rebase=False,
                                  keep=args.keep, force_delete=False,
-                                 tagging_info=tagging_info)
+                                 tagging_info=tagging_info, push=args.push)
 
     #- publish
     @classmethod
